ExpiringMemoryStore

Struct ExpiringMemoryStore 

pub struct ExpiringMemoryStore { /* private fields */ }
Why? The tower_session MemoryStore by default does not delete entries in time. Which may cause memory leak over long run. Java’s auto session management has no memory leak issue. Rust Axum should not have that issue, too!

The ExpiringMemoryStore automatically deletes object that is expired The data is stored internally as Arc<RwLock<HashMap<Id, Record>> The expiry is tracked by the ascending VecDequeue using creation time

Upon create, a background tokio thread is immediately started to delete expired session automatically every 5 seconds. Upon dropping the ExpiringMemoryStore, the background tokio thread is automatically cancelled. #Example

use axum::routing::get;
use axum::Router;
use std::net::SocketAddr;
use tower_sessions::{cookie::time::{self, Duration, OffsetDateTime}, Expiry, Session, SessionManagerLayer};
 
#[tokio::main]
async fn main() {
  let session_store = tower_sessions_auto_memory_store::ExpiringMemoryStore::new();
  let session_layer = SessionManagerLayer::new(session_store)
     .with_secure(false)
     .with_expiry(Expiry::OnInactivity(Duration::seconds(1800)));
  let app = Router::new()
     .route("/debug/test", get(root))
     .layer(session_layer);
   let addr = SocketAddr::from(([0, 0, 0, 0], 3000));
   println!("listening on {}", addr);
   axum_server::bind(addr)
     .serve(app.into_make_service())
     .await
     .unwrap();
}
 
async fn root() -> &'static str {
  "Hello, World!"
}

Implementations

Source

impl ExpiringMemoryStore

pub fn new() -> Self

Create a new ExpiringMemoryStore